<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans https://git.spip.net/spip/spip.git
return [

	// A
	'activer_plugin' => 'Activer le plugin',
	'affichage' => 'Affichage',
	'aide_non_disponible' => 'Cette partie de l’aide en ligne n’est pas encore disponible dans cette langue.',
	'annuler_recherche' => 'Annuler la recherche',
	'auteur' => 'Auteur :',
	'avis_acces_interdit' => 'Accès interdit.',
	'avis_acces_interdit_prive' => 'Vous n’avez pas le droit d’accéder à la page <b>@exec@</b>.',
	'avis_article_modifie' => 'Attention, @nom_auteur_modif@ a travaillé sur cet article il y a @date_diff@ minutes',
	'avis_aucun_resultat' => 'Aucun résultat.',
	'avis_base_inaccessible' => 'Impossible de se connecter à la base de données @base@.',
	'avis_chemin_invalide_1' => 'Le chemin que vous avez choisi',
	'avis_chemin_invalide_2' => 'ne semble pas valide. Veuillez retourner à la page précédente et vérifier les informations fournies.',
	'avis_connexion_echec_1' => 'La connexion  à la base de données a échoué.',
	'avis_connexion_echec_2' => 'Revenez à la page précédente, et vérifiez les informations que vous avez fournies.',
	'avis_connexion_echec_3' => '<b>N.B.</b> Sur de nombreux serveurs, vous devez <b>demander</b> l’activation de votre accès à la base de données avant de pouvoir l’utiliser. Si vous ne pouvez vous connecter, vérifiez que vous avez effectué cette démarche.',
	'avis_connexion_erreur_creer_base' => 'La base de données n’a pas pu être créée.',
	'avis_connexion_erreur_fichier_cle_manquant_1' => 'L’installation doit être faite par un·e webmestre avec un backup des clés et son mot de passe',
	'avis_connexion_erreur_fichier_cle_manquant_2' => 'L’installation doit être faite par un·e webmestre avec un backup des clés',
	'avis_connexion_erreur_nom_base' => 'Le nom de la base ne peut contenir que des lettres, des chiffres et des tirets',
	'avis_connexion_ldap_echec_1' => 'La connexion au serveur LDAP a échoué.',
	'avis_connexion_ldap_echec_2' => 'Revenez à la page précédente, et vérifiez les informations que vous avez fournies.',
	'avis_connexion_ldap_echec_3' => 'Alternativement, n’utilisez pas le support LDAP pour importer des comptes.',
	'avis_deplacement_rubrique' => 'Attention ! Cette rubrique contient @contient_breves@ brève@scb@ : si vous la déplacez, veuillez cocher cette case de confirmation.',
	'avis_erreur_connexion_mysql' => 'Erreur de connexion SQL',
	'avis_erreur_creation_compte' => 'Echec lors de l’initialisation du compte',
	'avis_espace_interdit' => '<b>Espace interdit</b> <div>SPIP est déjà installé.</div>',
	'avis_lecture_noms_bases_1' => 'Le programme d’installation n’a pas pu lire les noms des bases de données installées.',
	'avis_lecture_noms_bases_2' => 'Soit aucune base n’est disponible, soit la fonction permettant de lister les bases a été désactivée
		pour des raisons de sécurité (ce qui est le cas chez de nombreux hébergeurs).',
	'avis_lecture_noms_bases_3' => 'Dans la seconde alternative, il est probable qu’une base portant votre nom de login soit utilisable :',
	'avis_non_acces_page' => 'Vous n’avez pas accès à cette page.',
	'avis_operation_echec' => 'L’opération a échoué.',
	'avis_operation_impossible' => 'Opération impossible',
	'avis_suppression_base' => 'ATTENTION, la suppression des données est irréversible',

	// B
	'bouton_acces_ldap' => 'Ajouter l’accès à LDAP',
	'bouton_ajouter' => 'Ajouter',
	'bouton_annuler' => 'Annuler',
	'bouton_cache_activer' => 'Réactiver le cache',
	'bouton_cache_desactiver' => 'Désactiver temporairement le cache',
	'bouton_demande_publication' => 'Demander la publication de cet article',
	'bouton_desactive_tout' => 'Tout désactiver',
	'bouton_desinstaller' => 'Désinstaller',
	'bouton_effacer_tout' => 'Effacer TOUT',
	'bouton_envoyer_message' => 'Message définitif : envoyer',
	'bouton_fermer' => 'Fermer',
	'bouton_mettre_a_jour' => 'Mettre à jour',
	'bouton_mettre_a_jour_base' => 'Mettre à jour la base de données',
	'bouton_modifier' => 'Modifier',
	'bouton_radio_afficher' => 'Afficher',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Apparaître dans la liste des personnes connectées',
	'bouton_radio_envoi_annonces_adresse' => 'Envoyer les annonces à l’adresse :',
	'bouton_radio_envoi_liste_nouveautes' => 'Envoyer la liste des nouveautés',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Ne pas apparaître dans la liste des personnes connectées',
	'bouton_radio_non_envoi_annonces_editoriales' => 'Ne pas envoyer d’annonces éditoriales',
	'bouton_redirection' => 'REDIRECTION',
	'bouton_reinitialiser_aux_valeurs_par_defaut' => 'Réinitialiser aux valeurs par défaut',
	'bouton_relancer_inscription' => 'Relancer l’inscription',
	'bouton_relancer_inscriptions' => 'Relancer les inscriptions',
	'bouton_relancer_installation' => 'Relancer l’installation',
	'bouton_reset_password' => 'Envoyer un lien pour choisir son mot de passe',
	'bouton_suivant' => 'Suivant',
	'bouton_tenter_recuperation' => 'Tenter une réparation',
	'bouton_test_proxy' => 'Essayer le proxy',
	'bouton_vider_cache' => 'Vider le cache',

	// C
	'cache_modifiable_webmestre' => 'Ce paramètre est modifiable par un·e webmestre du site.',
	'calendrier_synchro' => 'Si vous utilisez un logiciel d’agenda compatible <b>iCal</b>, vous pouvez le synchroniser avec les informations de ce site.',
	'config_activer_champs' => 'Activer les champs suivants',
	'config_choix_base_sup' => 'indiquer une base sur ce serveur',
	'config_erreur_base_sup' => 'SPIP n’a pas accès à la liste des bases accessibles',
	'config_info_base_sup' => 'Si vous avez d’autres bases de données à interroger à travers SPIP, avec son serveur SQL ou avec un autre, le formulaire ci-dessous, vous permet de les déclarer. Si vous laissez certains champs vides, les identifiants de connexion à la base principale seront utilisés.',
	'config_info_base_sup_disponibles' => 'Bases supplémentaires déjà interrogeables :',
	'config_info_enregistree' => 'La nouvelle configuration a été enregistrée',
	'config_info_logos' => 'Chaque élément du site peut avoir un logo, ainsi qu’un « logo de survol »',
	'config_info_logos_utiliser' => 'Utiliser les logos',
	'config_info_logos_utiliser_non' => 'Ne pas utiliser les logos',
	'config_info_logos_utiliser_survol' => 'Utiliser les logos de survol',
	'config_info_logos_utiliser_survol_non' => 'Ne pas utiliser les logos de survol',
	'config_info_redirection' => 'En activant cette option, vous pourrez créer des articles virtuels, simples références d’articles publiés sur d’autres sites ou hors de SPIP.',
	'config_redirection' => 'Articles virtuels',
	'config_titre_base_sup' => 'Déclaration d’une base supplémentaire',
	'config_titre_base_sup_choix' => 'Choisissez une base supplémentaire',
	'connexion_ldap' => 'Connexion :',
	'creer_et_associer_un_auteur' => 'Créer et associer un auteur',

	// D
	'date_mot_heures' => 'heures',

	// E
	'ecran_connexion_couleur_principale' => 'Couleur principale',
	'ecran_connexion_image_fond' => 'Image de fond',
	'ecran_connexion_image_fond_explication' => 'Utiliser une image (format JPEG, 1920x1080 pixels)',
	'ecran_connexion_image_revenir_couleur_defaut' => 'Revenir à la couleur par défaut',
	'ecran_connexion_titre' => 'Écran de connexion',
	'ecran_securite' => ' + écran de sécurité @version@',
	'email' => 'email',
	'email_2' => 'email :',
	'en_savoir_plus' => 'En savoir plus',
	'entree_adresse_annuaire' => 'Adresse de l’annuaire',
	'entree_adresse_email' => 'Votre adresse email',
	'entree_adresse_email_2' => 'Adresse email',
	'entree_base_donnee_1' => 'Adresse de la base de données',
	'entree_base_donnee_2' => '(Souvent cette adresse correspond à celle de votre site, parfois elle correspond à la mention « localhost », parfois elle est laissée totalement vide.)',
	'entree_biographie' => 'Courte biographie en quelques mots.',
	'entree_chemin_acces' => '<b>Entrer</b> le chemin d’accès :',
	'entree_cle_pgp' => 'Votre clé PGP',
	'entree_cle_pgp_2' => 'Clé PGP',
	'entree_contenu_rubrique' => '(Contenu de la rubrique en quelques mots.)',
	'entree_identifiants_connexion' => 'Vos identifiants de connexion...',
	'entree_identifiants_connexion_2' => 'Identifiants de connexion',
	'entree_informations_connexion_ldap' => 'Veuillez entrer dans ce formulaire les informations de connexion à votre annuaire LDAP.
	Ces informations doivent pouvoir vous être fournies par l’admin du système,
	ou du réseau.',
	'entree_infos_perso' => 'Qui êtes-vous ?',
	'entree_infos_perso_2' => 'Qui est l’auteur ?',
	'entree_interieur_rubrique' => 'À l’intérieur de la rubrique :',
	'entree_liens_sites' => '<b>Lien hypertexte</b> (référence, site à visiter...)',
	'entree_login' => 'Votre login',
	'entree_login_connexion_1' => 'Le login de connexion',
	'entree_login_connexion_2' => '(Correspond parfois à votre login d’accès au FTP ; parfois laissé vide)',
	'entree_mot_passe' => 'Votre mot de passe',
	'entree_mot_passe_1' => 'Le mot de passe de connexion',
	'entree_mot_passe_2' => '(Correspond parfois à votre mot de passe pour le FTP ; parfois laissé vide)',
	'entree_nom_fichier' => 'Veuillez entrer le nom du fichier @texte_compresse@ :',
	'entree_nom_pseudo' => 'Votre nom ou votre pseudo',
	'entree_nom_pseudo_1' => '(Votre nom ou votre pseudo)',
	'entree_nom_pseudo_2' => 'Nom ou pseudo',
	'entree_nom_site' => 'Le nom de votre site',
	'entree_nom_site_2' => 'Nom du site de l’auteur',
	'entree_nouveau_passe' => 'Nouveau mot de passe',
	'entree_passe_ldap' => 'Mot de passe',
	'entree_port_annuaire' => 'Le numéro de port de l’annuaire',
	'entree_signature' => 'Signature',
	'entree_titre_obligatoire' => '<b>Titre</b> [Obligatoire]<br />',
	'entree_url' => 'L’adresse (URL) de votre site',
	'entree_url_2' => 'Adresse (URL) du site',
	'erreur_connect_deja_existant' => 'Un serveur existe déjà avec ce nom',
	'erreur_contenu_suspect' => 'Texte échappé',
	'erreur_email_deja_existant' => 'Cette adresse email est déjà enregistrée.',
	'erreur_nom_connect_incorrect' => 'Ce nom de serveur n’est pas autorisé',
	'erreur_plugin_attribut_balise_manquant' => 'Attribut @attribut@ manquant dans la balise @balise@.',
	'erreur_plugin_desinstalation_echouee' => 'La désinstallation du plugin a échoué. Vous pouvez néanmoins le désactiver.',
	'erreur_plugin_fichier_absent' => 'Fichier absent',
	'erreur_plugin_fichier_def_absent' => 'Fichier de définition absent',
	'erreur_plugin_nom_fonction_interdit' => 'Nom de fonction interdit',
	'erreur_plugin_nom_manquant' => 'Nom du plugin manquant',
	'erreur_plugin_prefix_manquant' => 'Espace de nommage du plugin non défini',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; manquant dans le fichier de définition',
	'erreur_plugin_version_manquant' => 'Version du plugin manquante',
	'erreur_type_fichier' => 'Type de fichier incorrect',

	// H
	'htaccess_a_simuler' => 'Avertissement : la configuration de votre serveur HTTP ne tient pas compte des fichiers @htaccess@. Pour pouvoir assurer une bonne sécurité, il faut que vous modifiiez cette configuration sur ce point, ou bien que les constantes @constantes@ (définissables dans le fichier mes_options.php) aient comme valeur des répertoires en dehors de @document_root@.',
	'htaccess_inoperant' => 'htaccess inopérant',

	// I
	'ical_info1' => 'Cette page présente plusieurs méthodes pour rester en contact avec la vie de ce site.',
	'ical_info2' => 'Pour plus de renseignements sur toutes ces techniques, n’hésitez pas à consulter <a href="@spipnet@">la documentation de SPIP</a>.',
	'ical_info_calendrier' => 'Deux calendriers sont à votre disposition. Le premier est un plan du site annonçant tous les articles publiés. Le second contient les annonces éditoriales ainsi que vos derniers messages privés : il vous est réservé grâce à une clé personnelle, que vous pouvez modifier à tout moment en renouvelant votre mot de passe.',
	'ical_methode_http' => 'Téléchargement',
	'ical_methode_webcal' => 'Synchronisation (webcal://)',
	'ical_texte_prive' => 'Ce calendrier, à usage strictement personnel, vous informe de l’activité éditoriale privée de ce site (tâches et rendez-vous personnels, articles et brèves proposés...).',
	'ical_texte_public' => 'Ce calendrier vous permet de suivre l’activité publique de ce site (articles et brèves publiés).',
	'ical_texte_rss' => 'Vous pouvez syndiquer les nouveautés de ce site dans n’importe quel lecteur de fichiers au format XML/RSS (Rich Site Summary). C’est aussi le format qui permet à SPIP de lire les nouveautés publiées sur d’autres sites utilisant un format d’échange compatible (sites syndiqués).',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Mailing-list',
	'ical_titre_rss' => 'Fichiers de syndication',
	'icone_accueil' => 'Accueil',
	'icone_activer_cookie' => 'Activer le cookie de correspondance',
	'icone_activite' => 'Activité',
	'icone_admin_plugin' => 'Gestion des plugins',
	'icone_administration' => 'Maintenance',
	'icone_afficher_auteurs' => 'Afficher les auteurs',
	'icone_afficher_visiteurs' => 'Afficher les visiteurs',
	'icone_arret_discussion' => 'Ne plus participer à cette discussion',
	'icone_calendrier' => 'Calendrier',
	'icone_configuration' => 'Configuration',
	'icone_creer_auteur' => 'Créer un nouvel auteur et l’associer à cet article',
	'icone_creer_mot_cle' => 'Créer un nouveau mot-clé et le lier à cet article',
	'icone_creer_rubrique_2' => 'Créer une nouvelle rubrique',
	'icone_developpement' => 'Développement',
	'icone_edition' => 'Édition',
	'icone_ma_langue' => 'Ma langue',
	'icone_mes_infos' => 'Mes informations',
	'icone_mes_preferences' => 'Mes préférences',
	'icone_modifier_article' => 'Modifier cet article',
	'icone_modifier_rubrique' => 'Modifier cette rubrique',
	'icone_outils_rapides' => 'Créer',
	'icone_publication' => 'Publication',
	'icone_relancer_signataire' => 'Relancer le signataire',
	'icone_retour' => 'Retour',
	'icone_retour_article' => 'Retour à l’article',
	'icone_squelette' => 'Squelettes',
	'icone_suivi_publication' => 'Suivi de la publication',
	'icone_supprimer_cookie' => 'Supprimer le cookie de correspondance',
	'icone_supprimer_rubrique' => 'Supprimer cette rubrique',
	'icone_supprimer_signature' => 'Supprimer cette signature',
	'icone_valider_signature' => 'Valider cette signature',
	'image_administrer_rubrique' => 'Vous pouvez administrer cette rubrique',
	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.',
	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.',
	'info_1_article' => '1 article',
	'info_1_article_a_paraitre' => '1 article à paraître',
	'info_1_article_meme_rubrique' => '1 article dans la même rubrique',
	'info_1_article_propose' => '1 article proposé',
	'info_1_article_publie' => '1 article publié',
	'info_1_article_recent' => 'L’article le plus récent',
	'info_1_article_redac' => '1 article en cours de rédaction',
	'info_1_article_refuse' => '1 article refusé',
	'info_1_article_rubrique' => '1 article publié dans la rubrique',
	'info_1_auteur' => '1 auteur',
	'info_1_message' => '1 message',
	'info_1_mot_cle' => '1 mot-clé',
	'info_1_rubrique' => '1 rubrique',
	'info_1_visiteur' => '1 visiteur',
	'info_activer_cookie' => 'Vous pouvez activer un <b>cookie de correspondance</b>, ce qui vous
	permettra de passer facilement du site public au site privé.',
	'info_activer_menu_developpement' => 'Afficher le menu Développement',
	'info_admin_etre_webmestre' => 'Me donner les droits de webmestre',
	'info_admin_je_suis_webmestre' => 'Je suis <b>webmestre</b>',
	'info_admin_statuer_webmestre' => 'Donner à cet admin les droits de webmestre',
	'info_admin_webmestre' => 'Cet admin est <b>webmestre</b>',
	'info_administrateur' => 'Admin',
	'info_administrateur_1' => 'Admin',
	'info_administrateur_2' => 'du site (<i>utilisez avec précaution</i>)',
	'info_administrateur_site_01' => 'Si vous êtes admin du site, veuillez',
	'info_administrateur_site_02' => 'cliquer sur ce lien',
	'info_administrateurs' => 'Admins',
	'info_administrer_rubrique' => 'Vous pouvez administrer cette rubrique',
	'info_adresse' => 'à l’adresse :',
	'info_adresse_desinscription' => 'Adresse de désinscription :',
	'info_adresse_inscription' => 'Adresse d’inscription :',
	'info_adresse_url' => 'Adresse (URL) du site public',
	'info_afficher_par_nb' => 'Afficher par',
	'info_aide_en_ligne' => 'Aide en ligne SPIP',
	'info_ajout_image' => 'Lorsque vous ajoutez des images en tant que documents joints à un article,
		SPIP peut créer pour vous, automatiquement, des vignettes (miniatures) des
		images insérées. Cela permet par exemple de créer
		automatiquement une galerie ou un portfolio.',
	'info_ajouter_rubrique' => 'Ajouter une autre rubrique à administrer :',
	'info_annonce_nouveautes' => 'Annonce des nouveautés',
	'info_article' => 'article',
	'info_article_2' => 'articles',
	'info_article_a_paraitre' => 'Les articles post-datés à paraître',
	'info_articles_02' => 'articles',
	'info_articles_2' => 'Articles',
	'info_articles_auteur' => 'Les articles de cet auteur',
	'info_articles_miens' => 'Mes articles',
	'info_articles_tous' => 'Tous les articles',
	'info_articles_trouves' => 'Articles trouvés',
	'info_attente_validation' => 'Vos articles en attente de validation',
	'info_aucun_article' => 'Aucun article',
	'info_aucun_auteur' => 'Aucun auteur',
	'info_aucun_message' => 'Aucun message',
	'info_aucun_rubrique' => 'Aucune rubrique',
	'info_aujourdhui' => 'aujourd’hui :',
	'info_auteur_gere_rubriques' => 'Cet auteur gère les rubriques suivantes :',
	'info_auteur_gere_toutes_rubriques' => 'Cet auteur gère <b>toutes les rubriques</b>',
	'info_auteur_gere_toutes_rubriques_2' => 'Je gère <b>toutes les rubriques</b>',
	'info_auteurs' => 'Les auteurs',
	'info_auteurs_par_tri' => 'Auteurs@partri@',
	'info_auteurs_trouves' => 'Auteurs trouvés',
	'info_authentification_externe' => 'Authentification externe',
	'info_avertissement' => 'Avertissement',
	'info_barre_outils' => 'avec sa barre d’outils ?',
	'info_base_installee' => 'La structure de votre base de données est installée.',
	'info_bio' => 'Biographie',
	'info_cache_desactive' => 'Le cache est temporairement désactivé.',
	'info_chapeau' => 'Chapeau',
	'info_chapeau_2' => 'Chapeau :',
	'info_chemin_acces_1' => 'Options : <b>Chemin d’accès dans l’annuaire</b>',
	'info_chemin_acces_2' => 'Vous devez désormais configurer le chemin d’accès aux informations dans l’annuaire. Cette information est indispensable pour lire les données de l’annuaire.',
	'info_chemin_acces_annuaire' => 'Options : <b>Chemin d’accès dans l’annuaire</b>',
	'info_choix_base' => 'Troisième étape :',
	'info_classement_1' => '<sup>er</sup> sur @liste@',
	'info_classement_2' => '<sup>e</sup> sur @liste@',
	'info_code_acces' => 'N’oubliez pas vos propres codes d’accès !',
	'info_config_suivi' => 'Si cette adresse correspond à une mailing-list, vous pouvez indiquer ci-dessous l’adresse à laquelle les participants au site peuvent s’inscrire. Cette adresse peut être une URL (par exemple la page d’inscription à la liste par le Web), ou une adresse email dotée d’un sujet spécifique (par exemple : <tt>@adresse_suivi@?subject=subscribe</tt>) :',
	'info_config_suivi_explication' => 'Vous pouvez vous abonner à la mailing-list de ce site. Vous recevrez alors par courrier électronique les annonces d’articles et de brèves proposés à la publication.',
	'info_confirmer_passe' => 'Confirmer ce nouveau mot de passe :',
	'info_conflit_edition_avis_non_sauvegarde' => 'Attention, les champs suivants ont été modifiés par ailleurs. Vos modifications sur ces champs n’ont donc pas été enregistrées.',
	'info_conflit_edition_differences' => 'Différences :',
	'info_conflit_edition_version_enregistree' => 'La version enregistrée :',
	'info_conflit_edition_votre_version' => 'Votre version :',
	'info_connexion_base' => 'Essai de connexion à la base',
	'info_connexion_base_donnee' => 'Connexion à votre base de données',
	'info_connexion_ldap_ok' => '<b>La connexion LDAP a réussi.</b><p> Vous pouvez passer à l’étape suivante.</p>',
	'info_connexion_mysql' => 'Votre connexion SQL',
	'info_connexion_ok' => 'La connexion a réussi.',
	'info_contact' => 'Contact',
	'info_contenu_articles' => 'Contenu des articles',
	'info_contributions' => 'Contributions',
	'info_creation_paragraphe' => 'Pour créer des paragraphes, laissez simplement des lignes vides.',
	'info_creation_rubrique' => 'Avant de pouvoir écrire des articles,<br /> vous devez créer au moins une rubrique.<br />',
	'info_creation_tables' => 'Création des tables de la base',
	'info_creer_base' => '<b>Créer</b> une nouvelle base de données :',
	'info_dans_rubrique' => 'Dans la rubrique :',
	'info_date_publication_anterieure' => 'Date de rédaction antérieure :',
	'info_date_referencement' => 'DATE DE RÉFÉRENCEMENT DE CE SITE :',
	'info_derniere_etape' => 'C’est terminé !',
	'info_descriptif' => 'Descriptif :',
	'info_desinstaller_plugin' => 'supprime les données et désactive le plugin',
	'info_discussion_cours' => 'Discussions en cours',
	'info_ecrire_article' => 'Avant de pouvoir écrire des articles, vous devez créer au moins une rubrique.',
	'info_email_envoi' => 'Adresse email d’envoi (optionnel)',
	'info_email_envoi_txt' => 'Indiquez ici l’adresse à utiliser pour envoyer les emails (à défaut, l’adresse destinataire sera utilisée comme adresse d’envoi) :',
	'info_email_webmestre' => 'Adresse email du ou de la webmestre',
	'info_envoi_email_automatique' => 'Envoi de mails automatique',
	'info_envoyer_maintenant' => 'Envoyer maintenant',
	'info_erreur_version_base_plus_recente' => 'Erreur d’installation',
	'info_etape_suivante' => 'Passer à l’étape suivante',
	'info_etape_suivante_1' => 'Vous pouvez passer à l’étape suivante.',
	'info_etape_suivante_2' => 'Vous pouvez passer à l’étape suivante.',
	'info_exceptions_proxy' => 'Exceptions pour le proxy',
	'info_exportation_base' => 'exportation de la base vers @archive@',
	'info_facilite_suivi_activite' => 'Afin de faciliter le suivi de l’activité
		éditoriale du site, SPIP peut faire parvenir par mail, par exemple
		à une mailing-list, l’annonce des demandes de
		publication et des validations d’articles. Indiquer une ou plusieurs adresses, séparées par des virgules.',
	'info_fichiers_authent' => 'Fichiers d’authentification « .htpasswd »',
	'info_forums_abo_invites' => 'Votre site comporte des forums sur abonnement ; la création de compte est ouverte sur le site public.',
	'info_gauche_admin_bdd' => '<b>Cette page est uniquement accessible aux responsables du site.</b><p> Elle donne accès aux différentes
fonctions de gestion des bases de données. Certaines d’entre elles donnent lieu à un processus d’authentification spécifique, qui
exige d’avoir un accès FTP au site Web.</p>',
	'info_gauche_admin_tech' => '<b>Cette page est uniquement accessible aux responsables du site.</b><p> Elle donne accès aux différentes
fonctions de maintenance technique. Certaines d’entre elles donnent lieu à un processus d’authentification spécifique, qui
exige d’avoir un accès FTP au site Web.</p>',
	'info_gauche_auteurs' => 'Vous trouverez ici tous les auteurs du site.
 Leur statut est indiqué par la couleur de leur icone (admin = vert ; rédacteur = jaune).',
	'info_gauche_auteurs_exterieurs' => 'Les auteurs extérieurs, sans accès au site, sont indiqués par une icone bleue ;
		les auteurs effacés par une icone grise.',
	'info_gauche_messagerie' => 'La messagerie vous permet d’échanger des messages entre comptes, de conserver des pense-bêtes (pour votre usage personnel) ou d’afficher des annonces sur la page d’accueil de l’espace privé (si vous êtes admin).',
	'info_gauche_statistiques_referers' => 'Cette page présente la liste des <i>referers</i>, c’est-à-dire des sites contenant des liens menant vers votre propre site, uniquement pour hier et aujourd’hui ; cette liste est remise à zéro toutes les 24 heures.',
	'info_gauche_visiteurs_enregistres' => 'Vous trouverez ici les visiteurs enregistrés
	dans l’espace public du site (forums sur abonnement).',
	'info_generation_miniatures_images' => 'Génération de miniatures des images',
	'info_gerer_trad_objets' => '@objets@ : gérer les liens de traduction',
	'info_hebergeur_desactiver_envoi_email' => 'Certains hébergeurs désactivent l’envoi automatique de
		mails depuis leurs serveurs. Dans ce cas, les fonctionnalités suivantes
		de SPIP ne fonctionneront pas.',
	'info_hier' => 'hier :',
	'info_identification_publique' => 'Votre identité publique...',
	'info_image_process' => 'Veuillez sélectionner la meilleure méthode de fabrication des vignettes en cliquant sur l’image correspondante.',
	'info_image_process2' => 'Si aucune image n’apparaît, alors le serveur qui héberge votre site n’a pas été configuré pour utiliser de tels outils. Si vous souhaitez utiliser ces fonctions, contactez le responsable technique et demandez les extensions « GD » ou « Imagick ».',
	'info_images_auto' => 'Images calculées automatiquement',
	'info_informations_personnelles' => 'Informations personnelles',
	'info_inscription' => 'Inscription le',
	'info_inscription_automatique' => 'Inscription automatique de nouveaux comptes',
	'info_jeu_caractere' => 'Jeu de caractères du site',
	'info_jours' => 'jours',
	'info_laisser_champs_vides' => 'laisser ces champs vides)',
	'info_langues' => 'Langues du site',
	'info_ldap_ok' => 'L’authentification LDAP est installée.',
	'info_lien_hypertexte' => 'Lien hypertexte :',
	'info_liste_nouveautes_envoyee' => 'La liste des nouveautés a été envoyée',
	'info_liste_redacteurs_connectes' => 'Liste des personnes connectées',
	'info_login_existant' => 'Ce login existe déjà.',
	'info_login_trop_court' => 'Login trop court.',
	'info_login_trop_court_car_pluriel' => 'Le login doit contenir au moins @nb@ caractères.',
	'info_logos' => 'Les logos',
	'info_maximum' => 'maximum :',
	'info_meme_rubrique' => 'Dans la même rubrique',
	'info_message_en_redaction' => 'Vos messages en cours de rédaction',
	'info_message_technique' => 'Message technique :',
	'info_messagerie_interne' => 'Messagerie interne',
	'info_mise_a_niveau_base' => 'mise à niveau de votre base SQL',
	'info_mise_a_niveau_base_2' => '{{Attention !}} Vous avez installé une version
		des fichiers SPIP {antérieure} à celle qui se trouvait
		auparavant sur ce site : votre base de données risque d’être
		perdue et votre site ne fonctionnera plus.<br />{{Réinstallez les
		fichiers de SPIP.}}',
	'info_modification_enregistree' => 'Votre modification a été enregistrée',
	'info_modifier_auteur' => 'Modifier l’auteur :',
	'info_modifier_rubrique' => 'Modifier la rubrique :',
	'info_modifier_statut' => 'Modifier le statut',
	'info_modifier_titre' => 'Modifier : @titre@',
	'info_mon_site_spip' => 'Mon site SPIP',
	'info_moyenne' => 'moyenne :',
	'info_multi_cet_article' => 'Langue de cet article :',
	'info_multi_langues_choisies' => 'Veuillez sélectionner ci-après les langues à disposition pour rédiger.
		Les langues déjà utilisées dans votre site (affichées en premier) ne peuvent pas être désactivées.',
	'info_multi_objets' => '@objets@ : activer le menu de langue',
	'info_multi_secteurs' => '... seulement pour les rubriques situées à la racine ?',
	'info_nb_articles' => '@nb@ articles',
	'info_nb_articles_a_paraitre' => '@nb@ articles à paraître',
	'info_nb_articles_meme_rubrique' => '@nb@ articles dans la même rubrique',
	'info_nb_articles_proposes' => '@nb@ articles proposés',
	'info_nb_articles_publies' => '@nb@ articles publiés',
	'info_nb_articles_recents' => 'Les @nb@ articles les plus récents',
	'info_nb_articles_redacs' => '@nb@ articles en cours de rédaction',
	'info_nb_articles_refuses' => '@nb@ articles refusés',
	'info_nb_auteurs' => '@nb@ auteurs',
	'info_nb_messages' => '@nb@ messages',
	'info_nb_mots_cles' => '@nb@ mots-clés',
	'info_nb_rubriques' => '@nb@ rubriques',
	'info_nb_visiteurs' => '@nb@ visiteurs',
	'info_nom' => 'Nom',
	'info_nom_destinataire' => 'Nom du destinataire',
	'info_nom_pas_conforme' => 'les tags html ne sont pas autorisés',
	'info_nom_site' => 'Nom de votre site',
	'info_nombre_articles' => '@nb_articles@ articles,',
	'info_nombre_rubriques' => '@nb_rubriques@ rubriques,',
	'info_nombre_sites' => '@nb_sites@ sites,',
	'info_non_deplacer' => 'Ne pas déplacer...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP peut envoyer, régulièrement, l’annonce des dernières nouveautés du site
		(articles et brèves récemment publiés).',
	'info_non_envoi_liste_nouveautes' => 'Ne pas envoyer la liste des nouveautés',
	'info_non_modifiable' => 'ne peut pas être modifié',
	'info_non_suppression_mot_cle' => 'je ne veux pas supprimer ce mot-clé.',
	'info_notes' => 'Notes',
	'info_nouvel_article' => 'Nouvel article',
	'info_nouvelle_traduction' => 'Nouvelle traduction :',
	'info_numero_article' => 'ARTICLE NUMÉRO :',
	'info_obligatoire_02' => '(obligatoire)',
	'info_option_accepter_visiteurs' => 'Accepter la création de comptes visiteurs sur le site public',
	'info_option_ne_pas_accepter_visiteurs' => 'Refuser la création de comptes visiteurs',
	'info_options_avancees' => 'OPTIONS AVANCÉES',
	'info_ou' => 'ou...',
	'info_page_interdite' => 'Page interdite',
	'info_par_nom' => 'par nom',
	'info_par_nombre_article' => 'par nombre d’articles',
	'info_par_statut' => 'par statut',
	'info_par_tri' => '’(par @tri@)’',
	'info_passe_trop_court' => 'Mot de passe trop court.',
	'info_passe_trop_court_car_pluriel' => 'Le mot de passe doit contenir au moins @nb@ caractères.',
	'info_passes_identiques' => 'Les deux mots de passe ne sont pas identiques.',
	'info_plus_cinq_car' => 'plus de 5 caractères',
	'info_plus_cinq_car_2' => '(Plus de 5 caractères)',
	'info_plus_trois_car' => '(Plus de 3 caractères)',
	'info_popularite' => 'popularité : @popularite@ ; visites : @visites@',
	'info_post_scriptum' => 'Post-Scriptum',
	'info_post_scriptum_2' => 'Post-scriptum :',
	'info_pour' => 'pour',
	'info_preview_texte' => 'Il est possible de prévisualiser les différents éléments éditoriaux du site ayant au moins le statut « proposé », ainsi que les éléments en cours de rédaction dont on est l’auteur. Pour quel statut cette fonctionnalité doit-elle être disponible ?',
	'info_procedez_par_etape' => 'procédez étape par étape',
	'info_procedure_maj_version' => 'la procédure de mise à jour doit être lancée afin d’adapter
	la base de données à la nouvelle version de SPIP.',
	'info_proxy_ok' => 'Test du proxy réussi.',
	'info_ps' => 'P.-S.',
	'info_publier' => 'publier',
	'info_publies' => 'Vos articles publiés en ligne',
	'info_question_accepter_visiteurs' => 'Si les squelettes de votre site prévoient la création de comptes sans accès à l’espace privé, veuillez activer l’option ci-dessous :',
	'info_question_inscription_nouveaux_redacteurs' => 'Acceptez-vous de nouvelles inscriptions à
  partir du site public ? Si vous acceptez, les internautes pourront s’inscrire
  depuis un formulaire automatisé et accéderont alors à l’espace privé pour
  proposer leurs propres articles. <div class="notice">Lors de la phase d’inscription,
  les personnes reçoivent un courrier électronique automatique
  leur fournissant leurs codes d’accès au site privé. Certains
  hébergeurs désactivent l’envoi de mails depuis leurs
  serveurs : dans ce cas, l’inscription automatique est
  impossible.</div>',
	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes',
	'info_racine_site' => 'Racine du site',
	'info_recharger_page' => 'Veuillez recharger cette page dans quelques instants.',
	'info_recherche_auteur_zero' => 'Aucun résultat pour « @cherche_auteur@ ».',
	'info_recommencer' => 'Veuillez recommencer.',
	'info_redacteur_1' => 'Rédacteur',
	'info_redacteur_2' => 'ayant accès à l’espace privé (<i>recommandé</i>)',
	'info_redacteurs' => 'Rédacteurs',
	'info_redaction_en_cours' => 'EN COURS DE RÉDACTION',
	'info_redirection' => 'Redirection',
	'info_redirection_activee' => 'La redirection est activée.',
	'info_redirection_boucle' => 'Vous essayez de rediriger l’article sur lui-même.',
	'info_redirection_desactivee' => 'La redirection a été supprimée.',
	'info_refuses' => 'Vos articles refusés',
	'info_reglage_ldap' => 'Options : <b>Réglage de l’importation LDAP</b>',
	'info_renvoi_article' => '<b>Redirection.</b> Cet article renvoie à la page :',
	'info_reserve_admin' => 'Seuls les admins peuvent modifier cette adresse.',
	'info_restreindre_rubrique' => 'Restreindre la gestion à la rubrique :',
	'info_resultat_recherche' => 'Résultats de la recherche :',
	'info_rubriques' => 'Rubriques',
	'info_rubriques_02' => 'rubriques',
	'info_rubriques_trouvees' => 'Rubriques trouvées',
	'info_sans_titre' => 'Sans titre',
	'info_selection_chemin_acces' => '<b>Sélectionnez</b> ci-après le chemin d’accès dans l’annuaire :',
	'info_signatures' => 'signatures',
	'info_site' => 'Site',
	'info_site_2' => 'site :',
	'info_site_min' => 'site',
	'info_site_reference_2' => 'Site référencé',
	'info_site_web' => 'Site Web :',
	'info_sites' => 'sites',
	'info_sites_lies_mot' => 'Les sites référencés liés à ce mot-clé',
	'info_sites_proxy' => 'Utiliser un proxy',
	'info_sites_trouves' => 'Sites trouvés',
	'info_sous_titre' => 'Soustitre :',
	'info_statut' => 'Statut',
	'info_statut_administrateur' => 'Admin',
	'info_statut_auteur' => 'Statut de cet auteur :',
	'info_statut_auteur_2' => 'Je suis',
	'info_statut_auteur_a_confirmer' => 'Inscription à confirmer',
	'info_statut_auteur_autre' => 'Autre statut :',
	'info_statut_redacteur' => 'Rédacteur',
	'info_statut_utilisateurs_1' => 'Statut par défaut des comptes importés',
	'info_statut_utilisateurs_2' => 'Choisissez le statut qui est attribué aux personnes présentes dans l’annuaire LDAP lorsqu’elles se connectent pour la première fois. Vous pourrez par la suite modifier cette valeur au cas par cas.',
	'info_suivi_activite' => 'Suivi de l’activité éditoriale',
	'info_surtitre' => 'Surtitre :',
	'info_syndication_integrale_1' => 'Votre site propose des fichiers de syndication (voir « <a href="@url@">@titre@</a> »).',
	'info_syndication_integrale_2' => 'Souhaitez-vous transmettre les articles dans leur intégralité, ou ne diffuser qu’un résumé de quelques centaines de caractères ?',
	'info_table_prefix' => 'Vous pouvez modifier le préfixe du nom des tables de données (ceci est indispensable lorsque l’on souhaite installer plusieurs sites dans la même base de données). Ce préfixe s’écrit en lettres minuscules, non accentuées, et sans espace.',
	'info_taille_maximale_images' => 'SPIP va tester la taille maximale des images qu’il peut traiter (en millions de pixels).<br /> Les images plus grandes ne seront pas réduites.',
	'info_taille_maximale_vignette' => 'Taille maximale des vignettes générées par le système :',
	'info_terminer_installation' => 'Vous pouvez maintenant terminer la procédure d’installation standard.',
	'info_texte' => 'Texte',
	'info_texte_explicatif' => 'Texte explicatif',
	'info_texte_long' => '(le texte est long : il apparaît donc en plusieurs parties qui seront recollées après validation.)',
	'info_texte_message' => 'Texte de votre message',
	'info_texte_message_02' => 'Texte du message',
	'info_titre' => 'Titre :',
	'info_total' => 'total :',
	'info_tous_articles_en_redaction' => 'Tous les articles en cours de rédaction',
	'info_tous_articles_presents' => 'Tous les articles publiés dans cette rubrique',
	'info_tous_articles_refuses' => 'Tous les articles refusés',
	'info_tous_les' => 'tous les :',
	'info_tout_site' => 'Tout le site',
	'info_tout_site2' => 'L’article n’a pas été traduit dans cette langue.',
	'info_tout_site3' => 'L’article a été traduit dans cette langue, mais des modifications ont été apportées par la suite à l’article de référence. La traduction doit être mise à jour.',
	'info_tout_site4' => 'L’article a été traduit dans cette langue, et la traduction est à jour.',
	'info_tout_site5' => 'Article original.',
	'info_tout_site6' => '<b>Attention :</b> seuls les articles originaux sont affichés.
Les traductions sont associées à l’original,
dans une couleur qui indique leur état :',
	'info_traductions' => 'Traductions',
	'info_travail_colaboratif' => 'Travail collaboratif sur les articles',
	'info_un_article' => 'un article,',
	'info_un_site' => 'un site,',
	'info_une_rubrique' => 'une rubrique,',
	'info_une_rubrique_02' => '1 rubrique',
	'info_url' => 'URL :',
	'info_url_proxy' => 'URL du proxy',
	'info_url_proxy_pas_conforme' => 'l’URL du proxy n’est pas valide.',
	'info_url_site_pas_conforme' => 'l’URL du site n’est pas valide.',
	'info_url_test_proxy' => 'URL de test',
	'info_urlref' => 'Lien hypertexte :',
	'info_utilisation_spip' => 'Vous pouvez maintenant commencer à utiliser le système de publication assistée...',
	'info_version_base_plus_recente' => 'La version de SPIP en base de données est plus récente que celle que vous utilisez. Cette opération n’est pas supportée, mettez à jour votre installation.',
	'info_visites_par_mois' => 'Affichage par mois :',
	'info_visiteur_1' => 'Visiteur',
	'info_visiteur_2' => 'du site public',
	'info_visiteurs' => 'Visiteurs',
	'info_visiteurs_02' => 'Visiteurs du site public',
	'info_webmestre_forces' => '<code>@file_options@</code> définit actuellement les webmestres.',
	'install_adresse_base_hebergeur' => 'Adresse de la base de données attribuée par l’hébergeur',
	'install_connect_ok' => 'La nouvelle base a bien été déclarée sous le nom de serveur @connect@.',
	'install_echec_annonce' => 'L’installation va probablement échouer, ou aboutir à un site non fonctionnel...',
	'install_extension_mbstring' => 'SPIP ne fonctionne pas avec :',
	'install_extension_php_obligatoire' => 'SPIP exige l’extension php :',
	'install_login_base_hebergeur' => 'Login de connexion attribué par l’hébergeur',
	'install_nom_base_hebergeur' => 'Nom de la base attribué par l’hébergeur :',
	'install_pas_table' => 'Base actuellement sans tables',
	'install_pass_base_hebergeur' => 'Mot de passe de connexion attribué par l’hébergeur',
	'install_php_extension' => 'Les extensions suivantes sont manquantes : @extensions@',
	'install_php_version' => 'PHP version @version@ insuffisant (minimum = @minimum@)',
	'install_php_version_max' => 'PHP version @version@ trop récent (maximum = @maximum@)',
	'install_select_langue' => 'Sélectionnez une langue puis cliquez sur le bouton « suivant » pour lancer la procédure d’installation.',
	'install_select_type_db' => 'Indiquer le type de base de données :',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Serveur de base de données attribué par l’hébergeur',
	'install_table_prefix_hebergeur' => 'Préfixe de table attribué par l’hébergeur :',
	'install_tables_base' => 'Tables de la base',
	'install_types_db_connus' => 'SPIP sait utiliser <b>MySQL</b> (le plus répandu) et <b>SQLite</b>.',
	'install_types_db_connus_avertissement' => 'Le support de <b>PostgreSQL</b> est également proposé à titre experimental',
	'instituer_erreur_statut_a_change' => 'Le statut a déjà été modifié',
	'instituer_erreur_statut_a_definir' => 'Choisir un nouveau statut',
	'instituer_erreur_statut_non_autorise' => 'Vous ne pouvez pas choisir ce statut',
	'intem_redacteur' => 'rédacteur',
	'intitule_licence' => 'Licence',
	'item_accepter_inscriptions' => 'Accepter les inscriptions',
	'item_activer_messages_avertissement' => 'Activer les messages d’avertissement',
	'item_administrateur_2' => 'admin',
	'item_afficher_calendrier' => 'Afficher dans le calendrier',
	'item_autoriser_syndication_integrale' => 'Diffuser l’intégralité des articles dans les fichiers de syndication',
	'item_choix_administrateurs' => 'les admins',
	'item_choix_generation_miniature' => 'Générer automatiquement les miniatures des images.',
	'item_choix_non_generation_miniature' => 'Ne pas générer de miniatures des images.',
	'item_choix_redacteurs' => 'les rédacteurs',
	'item_choix_visiteurs' => 'les visiteurs du site public',
	'item_creer_fichiers_authent' => 'Créer les fichiers .htpasswd',
	'item_login' => 'Login',
	'item_messagerie_agenda' => 'Activer la messagerie et l’agenda',
	'item_mots_cles_association_articles' => 'aux articles',
	'item_mots_cles_association_rubriques' => 'aux rubriques',
	'item_mots_cles_association_sites' => 'aux sites référencés ou syndiqués.',
	'item_non' => 'Non',
	'item_non_accepter_inscriptions' => 'Ne pas accepter les inscriptions',
	'item_non_activer_messages_avertissement' => 'Pas de messages d’avertissement',
	'item_non_afficher_calendrier' => 'Ne pas afficher dans le calendrier',
	'item_non_autoriser_syndication_integrale' => 'Ne diffuser qu’un résumé',
	'item_non_creer_fichiers_authent' => 'Ne pas créer ces fichiers',
	'item_non_messagerie_agenda' => 'Désactiver la messagerie et l’agenda',
	'item_non_publier_articles' => 'Ne pas publier les articles avant la date de publication fixée.',
	'item_nouvel_auteur' => 'Nouvel auteur',
	'item_nouvelle_rubrique' => 'Nouvelle rubrique',
	'item_oui' => 'Oui',
	'item_publier_articles' => 'Publier les articles, quelle que soit leur date de publication.',
	'item_reponse_article' => 'Réponse à l’article',
	'item_visiteur' => 'visiteur',

	// J
	'jour_non_connu_nc' => 'n.c.',

	// L
	'label_bando_outils' => 'Barre d’outils',
	'label_bando_outils_afficher' => 'Afficher les outils',
	'label_bando_outils_masquer' => 'Masquer les outils',
	'label_choisir_timezone' => 'Fuseau horaire du site',
	'label_choix_langue' => 'Sélectionnez votre langue',
	'label_langue' => 'Langue',
	'label_nom_fichier_connect' => 'Indiquez le nom utilisé pour ce serveur',
	'label_slogan_site' => 'Slogan du site',
	'label_taille_ecran' => 'Largeur de l’écran',
	'label_texte_et_icones_navigation' => 'Menu de navigation',
	'label_texte_et_icones_page' => 'Affichage dans la page',
	'ldap_correspondance' => 'héritage du champ @champ@',
	'ldap_correspondance_1' => 'Héritage des champs LDAP',
	'ldap_correspondance_2' => 'Pour chacun des champs SPIP suivants, indiquer le nom du champ LDAP correspondant. Laisser vide pour ne pas le remplir, séparer par des espaces ou des virgules pour essayer plusieurs champs LDAP.',
	'lien_ajouter_auteur' => 'Ajouter cet auteur',
	'lien_ajouter_une_rubrique' => 'Ajouter cette rubrique',
	'lien_email' => 'email',
	'lien_nom_site' => 'NOM DU SITE :',
	'lien_rapide_contenu' => 'Aller au contenu',
	'lien_rapide_navigation' => 'Aller à la navigation',
	'lien_rapide_recherche' => 'Aller à la recherche',
	'lien_retirer_auteur' => 'Retirer l’auteur',
	'lien_retirer_rubrique' => 'Retirer la rubrique',
	'lien_retirer_tous_auteurs' => 'Retirer tous les auteurs',
	'lien_retirer_toutes_rubriques' => 'Retirer toutes les rubriques',
	'lien_site' => 'site',
	'lien_tout_decocher' => 'Tout décocher',
	'lien_tout_deplier' => 'Tout déplier',
	'lien_tout_replier' => 'Tout replier',
	'lien_tout_supprimer' => 'Tout supprimer',
	'lien_trier_nom' => 'Trier par nom',
	'lien_trier_nombre_articles' => 'Trier par nombre d’articles',
	'lien_trier_statut' => 'Trier par statut',
	'lien_voir_en_ligne' => 'VOIR EN LIGNE :',
	'logo_article' => 'Logo de l’article',
	'logo_auteur' => 'Logo de l’auteur',
	'logo_rubrique' => 'Logo de la rubrique',
	'logo_site' => 'Logo de ce site',
	'logo_standard_rubrique' => 'Logo standard des rubriques',
	'logo_survol' => 'Logo pour survol',

	// M
	'menu_aide_installation_choix_base' => 'Choix de votre base',
	'module_fichier_langue' => 'Fichier de langue',
	'module_raccourci' => 'Raccourci',
	'module_texte_affiche' => 'Texte affiché',
	'module_texte_explicatif' => 'Vous pouvez insérer les raccourcis suivants dans les squelettes de votre site public. Ils seront automatiquement traduits dans les différentes langues pour lesquelles il existe un fichier de langue.',
	'module_texte_traduction' => 'Le fichier de langue « @module@ » est disponible en :',
	'mois_non_connu' => 'non connu',

	// N
	'nouvelle_version_spip' => 'La mise à jour @version@ de SPIP est disponible',
	'nouvelle_version_spip_majeure' => 'Une nouvelle version SPIP @version@ est disponible',

	// O
	'onglet_contenu' => 'Contenu',
	'onglet_declarer_une_autre_base' => 'Déclarer une autre base',
	'onglet_discuter' => 'Discuter',
	'onglet_interactivite' => 'Interactivité',
	'onglet_proprietes' => 'Propriétés',
	'onglet_repartition_actuelle' => 'actuellement',
	'onglet_sous_rubriques' => 'Sous-rubriques',

	// P
	'page_pas_proxy' => 'Cette page ne doit pas passer par le proxy',
	'pas_de_proxy_pour' => 'Au besoin, indiquez les machines ou domaines pour lesquels ce proxy ne doit pas s’appliquer (par exemple : @exemple@)',
	'phpinfo' => 'Configuration PHP',
	'plugin_charge_paquet' => 'Chargement du paquet @name@',
	'plugin_charger' => 'Télécharger',
	'plugin_erreur_charger' => 'erreur : impossible de charger @zip@',
	'plugin_erreur_droit1' => 'Le répertoire <code>@dest@</code> n’est pas accessible en écriture.',
	'plugin_erreur_droit2' => 'Veuillez vérifier les droits sur ce répertoire (et le créer le cas échéant), ou installer les fichiers par FTP.',
	'plugin_erreur_zip' => 'échec pclzip : erreur @status@',
	'plugin_etat_developpement' => 'en développement',
	'plugin_etat_experimental' => 'expérimental',
	'plugin_etat_stable' => 'stable',
	'plugin_etat_test' => 'en test',
	'plugin_impossible_activer' => 'Impossible d’activer le plugin @plugin@',
	'plugin_info_automatique1' => 'Si vous souhaitez autoriser l’installation automatique des plugins, veuillez :',
	'plugin_info_automatique1_lib' => 'Si vous souhaitez autoriser l’installation automatique de cette librairie, veuillez :',
	'plugin_info_automatique2' => 'créer un répertoire <code>@rep@</code> ;',
	'plugin_info_automatique3' => 'vérifier que le serveur est autorisé à écrire dans ce répertoire.',
	'plugin_info_automatique_creer' => 'à créer à la racine du site.',
	'plugin_info_automatique_exemples' => 'exemples :',
	'plugin_info_automatique_ftp' => 'Vous pouvez installer des plugins, par FTP, dans le répertoire <tt>@rep@</tt>',
	'plugin_info_automatique_lib' => 'Certains plugins demandent aussi à pouvoir télécharger des fichiers dans le répertoire <code>lib/</code>, à créer le cas échéant à la racine du site.',
	'plugin_info_automatique_liste' => 'Vos listes de plugins :',
	'plugin_info_automatique_liste_officielle' => 'les plugins officiels',
	'plugin_info_automatique_liste_update' => 'Mettre à jour les listes',
	'plugin_info_automatique_ou' => 'ou...',
	'plugin_info_automatique_select' => 'Sélectionnez ci-dessous un plugin : SPIP le téléchargera et l’installera dans le répertoire <code>@rep@</code> ; si ce plugin existe déjà, il sera mis à jour.',
	'plugin_info_credit' => 'Crédits',
	'plugin_info_erreur_xml' => 'La déclaration de ce plugin est incorrecte',
	'plugin_info_install_ok' => 'Installation réussie',
	'plugin_info_necessite' => 'Nécessite :',
	'plugin_info_non_compatible_spip' => 'Ce plugin n’est pas compatible avec cette version de SPIP',
	'plugin_info_plugins_dist_1' => 'Les plugins ci-dessous sont chargés et activés dans le répertoire @plugins_dist@.',
	'plugin_info_plugins_dist_2' => 'Ils ne sont pas désactivables.',
	'plugin_info_telecharger' => 'à télécharger depuis @url@ et à installer dans @rep@',
	'plugin_info_upgrade_ok' => 'Mise à jour réussie',
	'plugin_librairies_installees' => 'Librairies installées',
	'plugin_necessite_extension_php' => 'Nécessite l’extension PHP @plugin@ en version @version@.',
	'plugin_necessite_extension_php_sans_version' => 'Nécessite l’extension PHP @plugin@',
	'plugin_necessite_lib' => 'Ce plugin nécessite la librairie @lib@',
	'plugin_necessite_php' => 'Nécessite @plugin@ en version @version@.',
	'plugin_necessite_plugin' => 'Nécessite le plugin @plugin@ en version @version@.',
	'plugin_necessite_plugin_sans_version' => 'Nécessite le plugin @plugin@',
	'plugin_necessite_spip' => 'Nécessite SPIP en version @version@ minimum.',
	'plugin_source' => 'source : ',
	'plugin_titre_automatique' => 'Installation automatique',
	'plugin_titre_automatique_ajouter' => 'Ajouter des plugins',
	'plugin_titre_installation' => 'Installation du plugin @plugin@',
	'plugin_titre_modifier' => 'Mes plugins',
	'plugin_utilise_extension_php' => 'L’extension PHP @plugin@ doit être en version @version@.',
	'plugin_utilise_php' => '@plugin@ doit être en version @version@.',
	'plugin_utilise_plugin' => 'Le plugin @plugin@ doit être en version @version@.',
	'plugin_zip_active' => 'Continuez pour l’activer',
	'plugin_zip_adresse' => 'indiquez ci-dessous l’adresse d’un fichier zip de plugin à télécharger, ou encore l’adresse d’une liste de plugins.',
	'plugin_zip_adresse_champ' => 'Adresse du plugin ou de la liste ',
	'plugin_zip_content' => 'Il contient les fichiers suivants (@taille@),<br />prêts à installer dans le répertoire <code>@rep@</code>',
	'plugin_zip_installe_finie' => 'Le fichier @zip@ a été décompacté et installé.',
	'plugin_zip_installe_rep_finie' => 'Le fichier @zip@ a été décompacté et installé dans le répertoire @rep@',
	'plugin_zip_installer' => 'Vous pouvez maintenant l’installer.',
	'plugin_zip_telecharge' => 'Le fichier @zip@ a été téléchargé',
	'plugins_actif_aucun' => 'Aucun plugin activé.',
	'plugins_actif_un' => 'Un plugin activé.',
	'plugins_actifs' => '@count@ plugins activés.',
	'plugins_actifs_liste' => 'Actifs',
	'plugins_compte' => '@count@ plugins',
	'plugins_disponible_un' => 'Un plugin disponible.',
	'plugins_disponibles' => '@count@ plugins disponibles.',
	'plugins_erreur' => 'Erreur dans les plugins : @plugins@',
	'plugins_liste' => 'Liste des plugins',
	'plugins_liste_dist' => 'Plugins verrouillés',
	'plugins_recents' => 'Plugins récents.',
	'plugins_tous_liste' => 'Tous',
	'plugins_vue_hierarchie' => 'Hiérarchie',
	'plugins_vue_liste' => 'Liste',
	'protocole_ldap' => 'Version du protocole :',

	// Q
	'queue_args_fonction_label' => 'Arguments passés à la fonction @fonction@',
	'queue_args_voir' => 'Voir les arguments',
	'queue_executer_maintenant' => 'Exécuter maintenant',
	'queue_fonction_label' => 'Fonction',
	'queue_info_purger' => 'Vous pouvez supprimer toutes les tâches de fond en attente et réinitialiser la liste avec les tâches périodiques',
	'queue_liens_label' => 'Liens',
	'queue_nb_jobs_in_queue' => '@nb@ tâches en attente',
	'queue_next_job_in_nb_sec' => 'Prochaine tâche dans @nb@ s',
	'queue_next_job_scheduled' => 'Prochaine tâche',
	'queue_no_job_in_queue' => 'Aucune tâche en attente',
	'queue_one_job_in_queue' => '1 tâche en attente',
	'queue_priorite_tache' => 'priorité',
	'queue_purger_queue' => 'Réinitialiser la liste des tâches',
	'queue_statut_en_cours' => 'En cours',
	'queue_titre' => 'Tâches de fond',

	// R
	'repertoire_plugins' => 'Répertoire :',
	'required' => '(obligatoire)',

	// S
	'sans_heure' => 'sans heure',
	'statut_admin_restreint' => 'admin restreint',
	'statut_webmestre' => 'webmestre',

	// T
	'tache_cron_asap' => 'Tâche CRON @function@ (ASAP)',
	'tache_cron_secondes' => 'Tâche CRON @function@ (toutes les @nb@ s)',
	'taille_cache_image' => 'Les images calculées automatiquement par SPIP (vignettes des documents, titres présentés sous forme graphique, fonctions mathématiques au format TeX...) occupent dans le répertoire @dir@ un total de @taille@.',
	'taille_cache_moins_de' => 'La taille du cache est de moins de @octets@.',
	'taille_cache_octets' => 'La taille du cache est actuellement de @octets@ environ.',
	'taille_cache_vide' => 'Le cache est vide.',
	'taille_repertoire_cache' => 'Taille du répertoire cache',
	'text_article_propose_publication' => 'Article proposé pour la publication.',
	'texte_acces_ldap_anonyme_1' => 'Certains serveurs LDAP n’acceptent aucun accès anonyme. Dans ce cas il faut spécifier un identifiant d’accès initial afin de pouvoir ensuite rechercher des informations dans l’annuaire. Dans la plupart des cas néanmoins, les champs suivants pourront être laissés vides.',
	'texte_admin_effacer_01' => 'Cette commande efface <i>tout</i> le contenu de la base de données,
y compris <i>tous</i> les accès à l’espace privé. Après l’avoir exécutée, vous devrez lancer la
réinstallation de SPIP pour recréer une nouvelle base ainsi qu’un premier accès admin.',
	'texte_adresse_annuaire_1' => '(Si votre annuaire est installé sur la même machine que ce site Web, il s’agit probablement de « localhost ».)',
	'texte_ajout_auteur' => 'L’auteur suivant a été ajouté à l’article :',
	'texte_annuaire_ldap_1' => 'Si vous avez accès à un annuaire (LDAP), vous pouvez l’utiliser pour importer automatiquement des comptes sous SPIP.',
	'texte_article_statut' => 'Cet article est :',
	'texte_article_virtuel' => 'Article virtuel',
	'texte_article_virtuel_reference' => '<b>Article virtuel :</b> article référencé dans votre site SPIP, mais redirigé vers une autre URL. Pour supprimer la redirection, effacez l’URL ci-dessus.',
	'texte_aucun_resultat_auteur' => 'Aucun résultat pour "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'L’espace privé affiche en permanence la liste des personnes qui y sont connectées, ce qui vous permet d’échanger des messages en direct. Vous pouvez décider de ne pas apparaître dans cette liste (vous êtes « invisible » pour les autres).',
	'texte_auteurs' => 'LES AUTEURS',
	'texte_choix_base_1' => 'Choisissez votre base :',
	'texte_choix_base_2' => 'Le serveur SQL contient plusieurs bases de données.',
	'texte_choix_base_3' => '<b>Sélectionnez</b> ci-après celle qui vous a été attribuée par votre hébergeur :',
	'texte_choix_table_prefix' => 'Préfixe des tables :',
	'texte_compte_element' => '@count@ élément',
	'texte_compte_elements' => '@count@ éléments',
	'texte_conflit_edition_correction' => 'Veuillez contrôler ci-dessous les différences entre les deux versions du texte ; vous pouvez aussi copier vos modifications, puis recommencer.',
	'texte_connexion_mysql' => 'Consultez les informations fournies par votre hébergeur : vous devez y trouver le serveur de base de données qu’il propose et vos identifiants personnels pour vous y connecter.',
	'texte_contenu_article' => '(Contenu de l’article en quelques mots.)',
	'texte_contenu_articles' => 'Selon la maquette adoptée pour votre site, vous pouvez décider
		que certains éléments des articles ne sont pas utilisés.
		Utilisez la liste ci-dessous pour indiquer quels éléments sont disponibles.',
	'texte_crash_base' => 'Si votre base de données a
			crashé, vous pouvez tenter une réparation
			automatique.',
	'texte_creer_rubrique' => 'Avant de pouvoir écrire des articles,<br /> vous devez créer une rubrique.',
	'texte_date_creation_article' => 'DATE DE CRÉATION DE L’ARTICLE :', # on ajoute le ":"
	'texte_date_creation_objet' => 'Date de création :', # on ajoute le ":"
	'texte_date_publication_anterieure' => 'Date de rédaction antérieure :',
	'texte_date_publication_anterieure_nonaffichee' => 'Ne pas afficher de date de rédaction antérieure.',
	'texte_date_publication_article' => 'DATE DE PUBLICATION EN LIGNE :',
	'texte_date_publication_objet' => 'Date de publication en ligne :',
	'texte_definir_comme_traduction_rubrique' => 'Cette rubrique est une traduction de la rubrique numéro :',
	'texte_descriptif_rapide' => 'Descriptif rapide',
	'texte_effacer_base' => 'Effacer la base de données SPIP',
	'texte_effacer_statistiques' => 'Effacer les statistiques',
	'texte_en_cours_validation' => 'Les contenus ci-dessous sont en attente de validation.',
	'texte_enrichir_mise_a_jour' => 'Vous pouvez enrichir la mise en page de votre texte en utilisant des « raccourcis typographiques ».',
	'texte_fichier_authent' => '<b>SPIP doit-il créer les fichiers spéciaux
<tt>.htpasswd</tt> et <tt>.htpasswd-admin</tt> dans le répertoire @dossier@ ?</b>
<p>Ces fichiers peuvent vous servir à restreindre l’accès aux personnes connectées en d’autres endroits de votre site (programme externe de statistiques, par exemple).</p>
<p>Si vous n’en avez pas l’utilité, vous pouvez laisser cette option à sa valeur par défaut (pas de création des fichiers).</p>',
	'texte_informations_personnelles_1' => 'Le système va maintenant vous créer un accès personnalisé au site.',
	'texte_informations_personnelles_2' => '(Note : il s’agit d’une réinstallation, si votre accès marche toujours vous pouvez',
	'texte_introductif_article' => '(Texte introductif de l’article.)',
	'texte_jeu_caractere' => 'Il est conseillé d’employer, sur votre site, l’alphabet universel (<tt>utf-8</tt>) : celui-ci permet l’affichage de textes dans toutes les langues, et ne pose plus de problèmes de compatibilité avec les navigateurs modernes.',
	'texte_jeu_caractere_3' => 'Votre site est actuellement installé dans le jeu de caractères :',
	'texte_jeu_caractere_4' => 'Si cela ne correspond pas à la réalité de vos données (suite, par exemple, à une restauration de base de données), ou si <em>vous démarrez ce site</em> et souhaitez partir sur un autre jeu de caractères, veuillez indiquer ce dernier ici :',
	'texte_login_ldap_1' => '(Laisser vide pour un accès anonyme, ou entrer le chemin complet, par exemple « <tt>uid=dupont, ou=users, dc=mon-domaine, dc=com</tt> ».)',
	'texte_login_precaution' => 'Attention ! Ceci est le login sous lequel vous êtes connecté actuellement.
	Utilisez ce formulaire avec précaution...',
	'texte_messagerie_agenda' => 'Cette messagerie permet d’échanger dans l’espace privé du site. Elle est associée à un agenda.',
	'texte_mise_a_niveau_base_1' => 'Vous venez de mettre à jour les fichiers SPIP.
	Il faut maintenant mettre à niveau la base de données
	du site.',
	'texte_modifier_article' => 'Modifier l’article :',
	'texte_multilinguisme' => 'Si vous souhaitez gérer des objets en plusieurs langues, avec une navigation complexe, vous pouvez ajouter un menu de sélection de langue sur ces objets, en fonction de l’organisation de votre site.',
	'texte_multilinguisme_trad' => 'Vous pouvez également activer un système de gestion de liens entre les différentes traductions sur certains objets.',
	'texte_non_compresse' => '<i>non compressé</i> (votre serveur ne supportant pas cette fonctionnalité)',
	'texte_nouvelle_version_spip_1' => 'Vous avez installé une nouvelle version de SPIP.',
	'texte_nouvelle_version_spip_2' => 'Cette nouvelle version nécessite une mise à jour plus complète qu’à l’accoutumée. Si vous êtes webmestre du site, veuillez effacer le fichier @connect@ et reprendre l’installation afin de mettre à jour vos paramètres de connexion à la base de données.<p> (NB. : si vous avez oublié vos paramètres de connexion, jetez un œil au fichier @connect@ avant de le supprimer...)</p>',
	'texte_operation_echec' => 'Retournez à la page précédente, sélectionnez une autre base ou créez-en une nouvelle. Vérifiez les informations fournies par votre hébergeur.',
	'texte_plus_trois_car' => 'plus de 3 caractères',
	'texte_plusieurs_articles' => 'Plusieurs auteurs trouvés pour "@cherche_auteur@" :',
	'texte_port_annuaire' => '(La valeur indiquée par défaut convient généralement.)',
	'texte_presente_plugin' => 'Cette page liste les plugins disponibles sur le site. Vous pouvez activer les plugins nécessaires en cochant la case correspondante.',
	'texte_proposer_publication' => 'Lorsque votre article est terminé,<br /> vous pouvez proposer sa publication.',
	'texte_proxy' => 'Dans certains cas (intranet, réseaux protégés), les sites distants (documentation de SPIP, sites syndiqués, etc.) ne sont accessibles qu’à travers un <i>proxy HTTP</i>. Le cas échéant, indiquez ci-dessous son adresse, sous la forme @proxy_en_cours@. En général, vous laisserez cette case vide.',
	'texte_publication_articles_post_dates' => 'Quel comportement SPIP doit-il adopter face aux articles dont la
		date de publication a été fixée à une
		échéance future ?',
	'texte_rappel_selection_champs' => '[N’oubliez pas de sélectionner correctement ce champ.]',
	'texte_recalcul_page' => 'Si vous voulez
recalculer une seule page, passez plutôt par l’espace public et utilisez-y le bouton « recalculer ».',
	'texte_recuperer_base' => 'Réparer la base de données',
	'texte_reference_mais_redirige' => 'article référencé dans votre site SPIP, mais redirigé vers une autre URL.',
	'texte_requetes_echouent' => '<b>Lorsque certaines requêtes SQL échouent
  systématiquement et sans raison apparente, il est possible
  que ce soit à cause de la base de données
  elle-même.</b><p>
  Votre serveur SQL dispose d’une faculté de réparation de ses
  tables lorsqu’elles ont été endommagées par
  accident. Vous pouvez ici tenter cette réparation ; en
  cas d’échec, conservez une copie de l’affichage, qui contient
  peut-être des indices de ce qui ne va pas...</p><p>
  Si le problème persiste, prenez contact avec votre
  hébergeur.</p>',
	'texte_selection_langue_principale' => 'Vous pouvez sélectionner ci-dessous la « langue principale » du site. Ce choix ne vous oblige - heureusement ! - pas à écrire vos articles dans la langue sélectionnée, mais permet de déterminer :
	<ul><li> le format par défaut des dates sur le site public ;</li>
	<li> la nature du moteur typographique que SPIP doit utiliser pour le rendu des textes ;</li>
	<li> la langue utilisée dans les formulaires du site public ;</li>
	<li> la langue présentée par défaut dans l’espace privé.</li></ul>',
	'texte_sous_titre' => 'Sous-titre',
	'texte_statistiques_visites' => '(barres foncées :  dimanche / courbe foncée : évolution de la moyenne)',
	'texte_statut_attente_validation' => 'en attente de validation',
	'texte_statut_publies' => 'publiés en ligne',
	'texte_statut_refuses' => 'refusés',
	'texte_suppression_fichiers' => 'Utilisez cette commande afin de supprimer tous les fichiers présents
dans le cache SPIP. Cela permet par exemple de forcer un recalcul de toutes les pages si vous
avez fait des modifications importantes de graphisme ou de structure du site.',
	'texte_sur_titre' => 'Sur-titre',
	'texte_table_ok' => ' : cette table est OK.',
	'texte_tentative_recuperation' => 'Tentative de réparation',
	'texte_tenter_reparation' => 'Tenter une réparation de la base de données',
	'texte_test_proxy' => 'Pour faire un essai de ce proxy, indiquez ici l’adresse d’un site Web
				que vous souhaitez tester.',
	'texte_titre_02' => 'Titre :',
	'texte_titre_obligatoire' => '<b>Titre</b> [Obligatoire]',
	'texte_travail_article' => '@nom_auteur_modif@ a travaillé sur cet article il y a @date_diff@ minutes',
	'texte_travail_collaboratif' => 'S’il est fréquent que plusieurs personnes
		travaillent sur le même article, le système
		peut afficher les articles récemment « ouverts »
		afin d’éviter les modifications simultanées.
		Cette option est désactivée par défaut
		afin d’éviter d’afficher des messages d’avertissement
		intempestifs.',
	'texte_vide' => 'vide',
	'texte_vider_cache' => 'Vider le cache',
	'titre_admin_bdd' => 'Bases de données',
	'titre_admin_tech' => 'Maintenance technique',
	'titre_ajouter_un_auteur' => 'Ajouter un auteur',
	'titre_ajouter_un_mot' => 'Ajouter un mot-clé',
	'titre_cadre_afficher_article' => 'Afficher les articles',
	'titre_cadre_afficher_traductions' => 'Afficher l’état des traductions pour les langues suivantes :',
	'titre_cadre_ajouter_auteur' => 'AJOUTER UN AUTEUR :',
	'titre_cadre_interieur_rubrique' => 'À l’intérieur de la rubrique',
	'titre_cadre_numero_auteur' => 'AUTEUR NUMÉRO',
	'titre_cadre_numero_objet' => '@objet@ NUMÉRO :',
	'titre_cadre_signature_obligatoire' => '<b>Signature</b> [Obligatoire]<br />',
	'titre_config_contenu_notifications' => 'Notifications',
	'titre_config_contenu_prive' => 'Dans l’espace privé',
	'titre_config_contenu_public' => 'Sur le site public',
	'titre_config_fonctions' => 'Configuration du site',
	'titre_config_langage' => 'Configurer la langue',
	'titre_configuration' => 'Configuration du site',
	'titre_configurer_preferences' => 'Configurer vos préférences',
	'titre_configurer_preferences_menus' => 'Configurer vos préférences de menus',
	'titre_conflit_edition' => 'Conflit lors de l’édition',
	'titre_connexion_ldap' => 'Options : <b>Votre connexion LDAP</b>',
	'titre_groupe_mots' => 'GROUPE DE MOTS :',
	'titre_identite_site' => 'Identité du site',
	'titre_langue_article' => 'Langue de l’article',
	'titre_langue_rubrique' => 'Langue de la rubrique',
	'titre_langue_trad_article' => 'LANGUE ET TRADUCTIONS DE L’ARTICLE',
	'titre_les_articles' => 'LES ARTICLES',
	'titre_messagerie_agenda' => 'Messagerie et agenda',
	'titre_naviguer_dans_le_site' => 'Naviguer dans le site...',
	'titre_nouvelle_rubrique' => 'Nouvelle rubrique',
	'titre_numero_rubrique' => 'RUBRIQUE NUMÉRO :',
	'titre_page_articles_edit' => 'Modifier : @titre@',
	'titre_page_articles_page' => 'Les articles',
	'titre_page_articles_tous' => 'Tout le site',
	'titre_page_calendrier' => 'Calendrier @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Configuration du site',
	'titre_page_delete_all' => 'suppression totale et irréversible',
	'titre_page_recherche' => 'Résultats de la recherche @recherche@',
	'titre_page_statistiques_referers' => 'Statistiques (liens entrants)',
	'titre_page_upgrade' => 'Mise à niveau de SPIP',
	'titre_preference_menus_favoris' => 'Menus favoris',
	'titre_publication_articles_post_dates' => 'Publication des articles post-datés',
	'titre_reparation' => 'Réparation',
	'titre_suivi_petition' => 'Suivi des pétitions',
	'tls_ldap' => 'Transport Layer Security :',
	'trad_article_traduction' => 'Toutes les versions de cet article :',
	'trad_delier' => 'Ne plus lier à ces traductions',
	'trad_lier' => 'Cet article est une traduction de l’article numéro :',
	'trad_new' => 'Écrire une nouvelle traduction',

	// U
	'utf8_convert_erreur_orig' => 'Erreur : le jeu de caractères @charset@ n’est pas supporté.',

	// V
	'version' => 'Version :',
];
